@@ -48,9 +48,10 @@ class GtkObject:
 			v = v._o
 		_gtk.gtk_object_set(self._o, {key: v});
 	def __cmp__(self, other):
-		if hasattr(other, '_o'):
+	        if hasattr(other, '_o'):
 			return cmp(self._o, other._o)
-		return cmp(id(self), id(other))
+		else:
+			return cmp(id(self), id(other))
 	def flags(self, mask=None):
 		if mask:
 			return _gtk.GTK_OBJECT_FLAGS(self._o) & mask
@@ -1004,6 +1005,8 @@ class GtkTable(GtkContainer):
 		_gtk.gtk_table_set_row_spacings(self._o, s)
 	def set_col_spacings(self, s):
 		_gtk.gtk_table_set_col_spacings(self._o, s)
+	def set_homogeneous(self, homogeneous):
+	        _gtk.gtk_table_set_homogeneous(self._o, homogeneous)
 
 class GtkTree(GtkContainer):
 	def __init__(self, _obj=None):
@@ -1091,6 +1094,10 @@ class GtkCurve(GtkDrawingArea):
 		self._o = _gtk.gtk_curve_new()
 	def reset(self):
 		_gtk.gtk_curve_reset(self._o)
+	def get_vector(self, size=-1):
+		return _gtk.gtk_curve_get_vector(self._o, size)
+	def set_vector(self, vector):
+		_gtk.gtk_curve_set_vector(self._o, vector)
 	def set_gamma(self, g):
 		_gtk.gtk_curve_set_gamma(self._o, g)
 	def set_range(self, minx,maxx, miny,maxy):
@@ -1176,6 +1183,8 @@ class GtkSpinButton(GtkEntry):
 		_gtk.gtk_spin_button_set_numeric(self._o, numeric)
 	def spin(self, direction, step):
 		_gtk.gtk_spin_button_spin(self._o, direction, step)
+	def set_wrap(self, wrap):
+	        _gtk.gtk_spin_button_set_wrap(self._o, wrap)
 
 class GtkText(GtkEditable):
 	def __init__(self, hadj=None, vadj=None, _obj=None):
@@ -1274,6 +1283,8 @@ class GtkPreview(GtkWidget):
 		self._o = _gtk.gtk_preview_new(tp)
 	def size(self, w, h):
 		_gtk.gtk_preview_size(self._o, w, h)
+	def draw_row(self, data, x, y, w=None):
+		_gtk.gtk_preview_draw_row(self._o, data, x, y, w or len(data))
 	def set_expand(self, expand):
 		_gtk.gtk_preview_set_expand(self._o, expand)
 	def set_gamma(self, gamma):
