@@ -129,14 +129,13 @@ class Console(GtkVBox):
 		self.inp.show()
 
 		self.text = GtkText()
-		self.text.unset_flags(CAN_FOCUS)
 		self.text.set_editable(FALSE)
+		self.text.set_word_wrap(TRUE)
 		self.text.set_usize(500, 400)
 		self.inp.pack_start(self.text, padding=1)
 		self.text.show()
 
 		self.vscroll = GtkVScrollbar(self.text.get_vadjustment())
-		self.vscroll.unset_flags(CAN_FOCUS)
 		self.vscroll.set_update_policy(POLICY_AUTOMATIC)
 		self.inp.pack_end(self.vscroll, expand=FALSE)
 		self.vscroll.show()
@@ -152,7 +151,6 @@ class Console(GtkVBox):
 		self.prompt.show()
 
 		self.closer = GtkButton("Close")
-		self.closer.unset_flags(CAN_FOCUS)
 		self.closer.connect("clicked", self.quit)
 		self.inputbox.pack_end(self.closer, fill=FALSE, expand=FALSE)
 		self.closer.show()
@@ -206,6 +204,10 @@ class Console(GtkVBox):
 		if event.keyval == GDK.Return:
 			self.line.emit_stop_by_name("key_press_event")
 			self.eval()
+		if event.keyval == GDK.Tab:
+		        self.line.emit_stop_by_name("key_press_event")
+			self.line.append_text('\t')
+			idle_add(self.focus_text)
 		elif event.keyval in (GDK.KP_Up, GDK.Up):
 			self.line.emit_stop_by_name("key_press_event")
 			self.historyUp()
@@ -221,6 +223,7 @@ class Console(GtkVBox):
 
 	def focus_text(self):
 		self.line.grab_focus()
+		return FALSE  # don't requeue this handler
 
 	def ctrld(self):
 		self.quit()
