@@ -5,12 +5,16 @@ import GtkExtra
 
 wins = {}
 
+def delete_event(win, event=None):
+	win.hide()
+	# don't destroy window -- just leave it hidden
+	return TRUE
+
 def create_buttons(_button):
 	if not wins.has_key("buttons"):
 		win = GtkWindow()
 		wins["buttons"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("buttons")
 		box1 = GtkVBox()
 		win.add(box1)
@@ -57,8 +61,7 @@ def create_toggle_buttons(_button):
 	if not wins.has_key("toggle_buttons"):
 		win = GtkWindow()
 		wins["toggle_buttons"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("toggle butttons")
 		win.border_width(0)
 		box1 = GtkVBox()
@@ -94,8 +97,7 @@ def create_check_buttons(_button):
 	if not wins.has_key("check_buttons"):
 		win = GtkWindow()
 		wins["check_buttons"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("check buttons")
 		box1 = GtkVBox()
 		win.add(box1)
@@ -131,8 +133,7 @@ def create_radio_buttons(_button):
 	if not wins.has_key("radio_buttons"):
 		win = GtkWindow()
 		wins["radio_buttons"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("radio buttons")
 		box1 = GtkVBox()
 		win.add(box1)
@@ -172,8 +173,7 @@ def create_button_box(_button):
 		win = GtkDialog()
 		win.set_title("button box")
 		wins["button_box"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 
 		box1 = GtkHButtonBox()
 		box1.set_usize(550, -1)
@@ -300,8 +300,7 @@ def create_toolbar(_button):
 		wins["toolbar"] = win
 		win.set_title("Toolbar test")
 		win.set_policy(FALSE, TRUE, TRUE)
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.realize()
 		toolbar = make_toolbar(win)
 		win.add(toolbar)
@@ -313,8 +312,7 @@ def create_handle_box(_button):
 		win = GtkWindow()
 		wins["handle_box"] = win
 		win.set_title("Handle Box Test")
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.border_width(20)
 		win.realize()
 
@@ -331,8 +329,7 @@ def create_reparent(_button):
 	if not wins.has_key("reparent"):
 		win = GtkWindow()
 		wins["reparent"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("buttons")
 
 		box1 = GtkVBox()
@@ -397,8 +394,7 @@ def create_pixmap(_button):
 	if not wins.has_key("pixmap"):
 		win = GtkWindow()
 		wins["pixmap"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("pixmap")
 		win.realize()
 
@@ -447,8 +443,7 @@ def create_tooltips(_button):
 	if not wins.has_key("tooltips"):
 		win = GtkWindow()
 		wins["tooltips"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("tooltips")
 
 		tooltips = GtkTooltips()
@@ -501,8 +496,6 @@ def create_tooltips(_button):
 def create_menu(depth):
 	if depth < 1: return None
 	menu = GtkMenu()
-	#submenu = None
-	submenu = create_menu(depth - 1)
 	group = None
 	for i in range(5):
 		menuitem = GtkRadioMenuItem(group,
@@ -510,16 +503,15 @@ def create_menu(depth):
 		group = menuitem
 		menu.append(menuitem)
 		menuitem.show()
-		if depth > 0:
-			if submenu:
-				menuitem.set_submenu(submenu)
+		if depth > 1:
+		        submenu = create_menu(depth - 1)
+			menuitem.set_submenu(submenu)
 	return menu
 def create_menus(_button):
 	if not wins.has_key("menus"):
 		win = GtkWindow()
 		wins["menus"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("menus")
 
 		box1 = GtkVBox()
@@ -530,20 +522,18 @@ def create_menus(_button):
 		box1.pack_start(menubar, expand=FALSE)
 		menubar.show()
 
-		menu = create_menu(2)
-
 		menuitem = GtkMenuItem("test\nline2")
-		menuitem.set_submenu(menu)
+		menuitem.set_submenu(create_menu(2))
 		menubar.append(menuitem)
 		menuitem.show()
 
 		menuitem = GtkMenuItem("foo")
-		menuitem.set_submenu(menu)
+		menuitem.set_submenu(create_menu(2))
 		menubar.append(menuitem)
 		menuitem.show()
 
 		menuitem = GtkMenuItem("bar")
-		menuitem.set_submenu(menu)
+		menuitem.set_submenu(create_menu(2))
 		menuitem.right_justify()
 		menubar.append(menuitem)
 		menuitem.show()
@@ -579,8 +569,7 @@ def create_scrolled_windows(_button):
 	if not wins.has_key("scrolled_windows"):
 		win = GtkDialog()
 		wins["scrolled_windows"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("dialog")
 
 		scrolled_window = GtkScrolledWindow()
@@ -613,8 +602,7 @@ def create_entry(_button):
 	if not wins.has_key("entry"):
 		win = GtkWindow()
 		wins["entry"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("entry")
 
 		box1 = GtkVBox()
@@ -652,8 +640,7 @@ def create_list(_button):
 	if not wins.has_key("list"):
 		win = GtkWindow()
 		wins["list"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("list")
 
 		box1 = GtkVBox()
@@ -728,8 +715,7 @@ def create_clist(_button):
 	if not wins.has_key("clist"):
 		win = GtkWindow()
 		wins["clist"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("clist")
 
 		box1 = GtkVBox()
@@ -852,8 +838,7 @@ def create_color_selection(_button):
 		win.colorsel.set_opacity(TRUE)
 		win.colorsel.set_update_policy(UPDATE_CONTINUOUS)
 		win.position(WIN_POS_MOUSE)
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 
 		win.cancel_button.connect("clicked", win.hide)
 	wins["color_selection"].show()
@@ -862,8 +847,7 @@ def create_file_selection(_button):
 	if not wins.has_key("file_selection"):
 		win = GtkFileSelection("file selection dialog")
 		wins["file_selection"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		def file_selection_ok(_button, fs=win):
 			print fs.get_filename()
 		win.ok_button.connect("clicked", file_selection_ok)
@@ -874,8 +858,7 @@ def create_dialog(_button):
 	if not wins.has_key("dialog"):
 		win = GtkDialog()
 		wins["dialog"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("dialog")
 
 		button = GtkButton("OK")
@@ -907,8 +890,7 @@ def create_range_controls(_button):
 	if not wins.has_key("range_controls"):
 		win = GtkWindow()
 		wins["range_controls"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("range_controls")
 
 		box1 = GtkVBox()
@@ -956,8 +938,7 @@ def create_rulers(_button):
 	if not wins.has_key("rulers"):
 		win = GtkWindow()
 		wins["rulers"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("rulers")
 		win.set_usize(300, 300)
 		# these should be defined elsewhere
@@ -998,8 +979,7 @@ def create_text(_button):
 	if not wins.has_key("text"):
 		win = GtkWindow()
 		wins["text"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("text")
 
 		box1 = GtkVBox()
@@ -1069,8 +1049,7 @@ def create_notebook(_button):
 	if not wins.has_key("notebook"):
 		win = GtkWindow()
 		wins["notebook"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("notebook")
 
 		box1 = GtkVBox()
@@ -1138,8 +1117,7 @@ def create_panes(_button):
 	if not wins.has_key("panes"):
 		win = GtkWindow()
 		wins["panes"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("Panes")
 
 		vpaned = GtkVPaned()
@@ -1194,7 +1172,6 @@ def create_dnd(_button):
 			button.dnd_data_set(event, dnd_string)
 		win = GtkWindow(WINDOW_TOPLEVEL)
 		wins["dnd"] = win
-		win.connect("destroy", win.hide)
 		win.connect("delete_event", lambda win,_e: win.hide())
 		win.set_title("Drag -N- Drop")
 
@@ -1304,8 +1281,7 @@ def create_gamma_curve(_button):
 	if not wins.has_key("gamma_curve"):
 		win = GtkWindow()
 		wins["gamma_curve"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w, _e, win=win: win.hide()())
+		win.connect("delete_event", lambda _w, _e, win=win: win.hide())
 		win.set_title("test")
 		win.set_usize(200, 150)
 
@@ -1319,8 +1295,7 @@ def create_timeout_test(_button):
 	if not wins.has_key("timeout_test"):
 		win = GtkDialog()
 		wins["timeout_test"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("Timeout Test")
 
 		label = GtkLabel("count: 0")
@@ -1365,8 +1340,7 @@ def create_idle_test(_button):
 	if not wins.has_key("idle_test"):
 		win = GtkDialog()
 		wins["idle_test"] = win
-		win.connect("destroy", win.hide)
-		win.connect("delete_event", lambda _w,_e,win=win: win.hide())
+		win.connect("delete_event", delete_event)
 		win.set_title("Idle Test")
 
 		label = GtkLabel("count: 0")
